<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_Tab_Content extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'tp-tab-content';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Tab Services', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // TG_tab_Content_section
        $this->start_controls_section(
            'TG_tab_Content_section01',
            [
                'label' => esc_html__('Tab Services One', 'tpcore'),
            ]
        );

        $this->add_control(
            'tg_img01',
            [
                'label' => esc_html__('Choose Services Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tg_bg_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->add_control(
            'tg_services_title01',
            [
                'label' => esc_html__('Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Home Cleaning Services', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_services_desc01',
            [
                'label' => esc_html__('Description', 'tpcore'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Lorem ipsum dolor sit amet consectetur. Ut tellus suspendisse nulla aliquam. Risus rutrum tellus eget ultrices.', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_services_url01',
            [
                'label' => esc_html__('Services URL', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // TG_tab_Content_section
        $this->start_controls_section(
            'TG_tab_Content_section02',
            [
                'label' => esc_html__('Tab Services Two', 'tpcore'),
            ]
        );

        $this->add_control(
            'tg_img02',
            [
                'label' => esc_html__('Choose Services Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tg_bg_size2',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->add_control(
            'tg_services_title02',
            [
                'label' => esc_html__('Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Home Cleaning Services', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_services_desc02',
            [
                'label' => esc_html__('Description', 'tpcore'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Lorem ipsum dolor sit amet consectetur. Ut tellus suspendisse nulla aliquam. Risus rutrum tellus eget ultrices.', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_services_url02',
            [
                'label' => esc_html__('Services URL', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // TG_tab_Content_section
        $this->start_controls_section(
            'TG_tab_Content_section03',
            [
                'label' => esc_html__('Tab Services Three', 'tpcore'),
            ]
        );

        $this->add_control(
            'tg_img03',
            [
                'label' => esc_html__('Choose Services Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tg_bg_size3',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->add_control(
            'tg_services_title03',
            [
                'label' => esc_html__('Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Home Cleaning Services', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_services_desc03',
            [
                'label' => esc_html__('Description', 'tpcore'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Lorem ipsum dolor sit amet consectetur. Ut tellus suspendisse nulla aliquam. Risus rutrum tellus eget ultrices.', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_services_url03',
            [
                'label' => esc_html__('Services URL', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // STYLE TAB
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if (!empty($settings['tg_img01']['url'])) {
            $tg_img_url01 = !empty($settings['tg_img01']['id']) ? wp_get_attachment_image_url($settings['tg_img01']['id'], $settings['tg_bg_size_size']) : $settings['tg_img01']['url'];
            $tg_img_alt01 = get_post_meta($settings["tg_img01"]["id"], "_wp_attachment_image_alt", true);
        }

        if (!empty($settings['tg_img02']['url'])) {
            $tg_img_url02 = !empty($settings['tg_img02']['id']) ? wp_get_attachment_image_url($settings['tg_img02']['id'], $settings['tg_bg_size2_size']) : $settings['tg_img02']['url'];
            $tg_img_alt02 = get_post_meta($settings["tg_img02"]["id"], "_wp_attachment_image_alt", true);
        }

        if (!empty($settings['tg_img03']['url'])) {
            $tg_img_url03 = !empty($settings['tg_img03']['id']) ? wp_get_attachment_image_url($settings['tg_img03']['id'], $settings['tg_bg_size3_size']) : $settings['tg_img03']['url'];
            $tg_img_alt03 = get_post_meta($settings["tg_img03"]["id"], "_wp_attachment_image_alt", true);
        }

?>


        <div class="row">

            <div class="col-lg-6">
                <div class="project-item-two big-item">

                    <?php if (!empty($settings['tg_img01']['url'])) : ?>
                        <div class="project-thumb-two">
                            <a href="<?php echo esc_url($settings['tg_services_url01']); ?>">
                                <img src="<?php echo esc_url($tg_img_url01) ?>" alt="<?php echo esc_attr($tg_img_alt01) ?>">
                            </a>
                        </div>
                    <?php endif; ?>

                    <div class="project-content-two">
                        <?php if (!empty($settings['tg_services_url01'])) : ?>
                            <h2 class="title">
                                <a href="<?php echo esc_url($settings['tg_services_url01']); ?>">
                                    <?php echo tp_kses($settings['tg_services_title01']); ?>
                                </a>
                            </h2>
                        <?php endif; ?>

                        <?php if (!empty($settings['tg_services_desc01'])) : ?>
                            <p><?php echo tp_kses($settings['tg_services_desc01']); ?></p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <div class="col-lg-6">
                <div class="project-item-two small-item">

                    <?php if (!empty($settings['tg_img02']['url'])) : ?>
                        <div class="project-thumb-two">
                            <a href="<?php echo esc_url($settings['tg_services_url02']); ?>">
                                <img src="<?php echo esc_url($tg_img_url02) ?>" alt="<?php echo esc_attr($tg_img_alt02) ?>">
                            </a>
                        </div>
                    <?php endif; ?>

                    <div class="project-content-two">
                        <?php if (!empty($settings['tg_services_url02'])) : ?>
                            <h2 class="title">
                                <a href="<?php echo esc_url($settings['tg_services_url02']); ?>">
                                    <?php echo tp_kses($settings['tg_services_title02']); ?>
                                </a>
                            </h2>
                        <?php endif; ?>

                        <?php if (!empty($settings['tg_services_desc02'])) : ?>
                            <p><?php echo tp_kses($settings['tg_services_desc02']); ?></p>
                        <?php endif; ?>

                    </div>
                </div>

                <div class="project-item-two small-item">

                    <?php if (!empty($settings['tg_img03']['url'])) : ?>
                        <div class="project-thumb-two">
                            <a href="<?php echo esc_url($settings['tg_services_url03']); ?>">
                                <img src="<?php echo esc_url($tg_img_url03) ?>" alt="<?php echo esc_attr($tg_img_alt03) ?>">
                            </a>
                        </div>
                    <?php endif; ?>

                    <div class="project-content-two">
                        <?php if (!empty($settings['tg_services_url03'])) : ?>
                            <h2 class="title">
                                <a href="<?php echo esc_url($settings['tg_services_url03']); ?>">
                                    <?php echo tp_kses($settings['tg_services_title03']); ?>
                                </a>
                            </h2>
                        <?php endif; ?>

                        <?php if (!empty($settings['tg_services_desc03'])) : ?>
                            <p><?php echo tp_kses($settings['tg_services_desc03']); ?></p>
                        <?php endif; ?>
                    </div>
                </div>

            </div>
        </div>

<?php
    }
}

$widgets_manager->register(new TG_Tab_Content());
