<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;

use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Core\Schemes\Typography;
use \Elementor\Group_Control_Background;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_Fact extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'tp-fact';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Fact', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // layout Panel
        $this->start_controls_section(
            'tp_layout',
            [
                'label' => esc_html__('Design Layout', 'tpcore'),
            ]
        );
        $this->add_control(
            'tg_design_style',
            [
                'label' => esc_html__('Select Layout', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'tpcore'),
                    'layout-2' => esc_html__('Layout 2', 'tpcore'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->end_controls_section();

        // Fact group
        $this->start_controls_section(
            'tg_fact',
            [
                'label' => esc_html__('Fact List', 'tpcore'),
                'description' => esc_html__('Control all the style settings from Style tab', 'tpcore'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'tg_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'tpcore'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'image' => esc_html__('SVG Import', 'tpcore'),
                    'icon' => esc_html__('Icon', 'tpcore'),
                ],
            ]
        );

        $repeater->add_control(
            'tg_svg',
            [
                'label' => esc_html__('Import SVG Code', 'tpcore'),
                'type' => Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__('Paste SVG code', 'tpcore'),
                'label_block' => true,
                'condition' => [
                    'tg_icon_type' => 'image'
                ]
            ]
        );

        if (tp_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'tg_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'tg_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'tg_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'tg_icon_type' => 'icon'
                    ]
                ]
            );
        }

        $repeater->add_control(
            'tg_fact_number',
            [
                'label' => esc_html__('Number', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('2562', 'tpcore'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'tg_fact_formatting',
            [
                'label' => esc_html__('Formatting Mask', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('+', 'tpcore'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'tg_fact_desc',
            [
                'label' => esc_html__('Fact Description', 'tpcore'),
                'description' => tp_get_allowed_html_desc('intermediate'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Satisfied Clients', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_fact_list',
            [
                'label' => esc_html__('Fact Lists', 'tpcore'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'tg_fact_number' => esc_html__('2562', 'tpcore'),
                        'tg_fact_desc' => esc_html__('Satisfied Clients', 'tpcore'),
                    ],
                    [
                        'tg_fact_number' => esc_html__('176', 'tpcore'),
                        'tg_fact_desc' => esc_html__('Active Project', 'tpcore'),
                    ],
                    [
                        'tg_fact_number' => esc_html__('28', 'tpcore'),
                        'tg_fact_desc' => esc_html__('Winning Award', 'tpcore'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        // TAB_STYLE
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>

        <?php if ($settings['tg_design_style']  == 'layout-2') : ?>

            <script>
                jQuery(document).ready(function($) {

                    /*=============================================
                        =    		Odometer Active  	       =
                    =============================================*/
                    $('.odometer').appear(function(e) {
                        var odo = $(".odometer");
                        odo.each(function() {
                            var countNumber = $(this).attr("data-count");
                            $(this).html(countNumber);
                        });
                    });

                });
            </script>


            <div class="counter-area-three">
                <div class="row">

                    <?php foreach ($settings['tg_fact_list'] as $item) : ?>
                        <div class="col-lg-3 col-sm-6">
                            <div class="counter-item">
                                <div class="icon">
                                    <?php if ($item['tg_icon_type'] !== 'image') : ?>
                                        <?php if (!empty($item['tg_icon']) || !empty($item['tg_selected_icon']['value'])) : ?>
                                            <?php tp_render_icon($item, 'tg_icon', 'tg_selected_icon'); ?>
                                        <?php endif; ?>
                                    <?php else : ?>
                                        <?php echo tp_kses($item['tg_svg']); ?>
                                    <?php endif; ?>
                                </div>
                                <div class="content">
                                    <h2 class="count"><span class="odometer" data-count="<?php echo tp_kses($item['tg_fact_number']); ?>"></span><?php if (!empty($item['tg_fact_formatting'])) : ?><?php echo tp_kses($item['tg_fact_formatting']); ?><?php endif; ?></h2>
                                    <p><?php echo tp_kses($item['tg_fact_desc']); ?></p>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>

                </div>
            </div>


        <?php else : ?>

            <script>
                jQuery(document).ready(function($) {

                    /*=============================================
                        =    		Odometer Active  	       =
                    =============================================*/
                    $('.odometer').appear(function(e) {
                        var odo = $(".odometer");
                        odo.each(function() {
                            var countNumber = $(this).attr("data-count");
                            $(this).html(countNumber);
                        });
                    });

                });
            </script>


            <div class="row justify-content-center">

                <?php foreach ($settings['tg_fact_list'] as $item) : ?>
                    <div class="col-lg-3 col-sm-6">
                        <div class="counter-item">
                            <div class="icon">
                                <?php if ($item['tg_icon_type'] !== 'image') : ?>
                                    <?php if (!empty($item['tg_icon']) || !empty($item['tg_selected_icon']['value'])) : ?>
                                        <?php tp_render_icon($item, 'tg_icon', 'tg_selected_icon'); ?>
                                    <?php endif; ?>
                                <?php else : ?>
                                    <?php echo tp_kses($item['tg_svg']); ?>
                                <?php endif; ?>
                            </div>
                            <div class="content">
                                <h2 class="count"><span class="odometer" data-count="<?php echo tp_kses($item['tg_fact_number']); ?>"></span><?php if (!empty($item['tg_fact_formatting'])) : ?><?php echo tp_kses($item['tg_fact_formatting']); ?><?php endif; ?></h2>
                                <p><?php echo tp_kses($item['tg_fact_desc']); ?></p>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>

            </div>

        <?php endif; ?>

<?php
    }
}

$widgets_manager->register(new TG_Fact());
