<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Background;
use \Elementor\Control_Media;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_Hero_Banner extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'hero-banner';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Hero Banner', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // layout Panel
        $this->start_controls_section(
            'tp_layout',
            [
                'label' => esc_html__('Design Layout', 'tpcore'),
            ]
        );
        $this->add_control(
            'tg_design_style',
            [
                'label' => esc_html__('Select Layout', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'tpcore'),
                    'layout-2' => esc_html__('Layout 2', 'tpcore'),
                    'layout-3' => esc_html__('Layout 3', 'tpcore'),
                    'layout-4' => esc_html__('Layout 4', 'tpcore'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->end_controls_section();

        // _tg_image
        $this->start_controls_section(
            '_tg_bg_section',
            [
                'label' => esc_html__('Section Background', 'tpcore'),
                'condition' => [
                    'tg_design_style!' => ['layout-4'],
                ],
            ]
        );

        $this->add_control(
            'tg_bg',
            [
                'label' => esc_html__('Choose Background Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'tg_disable_parallax',
            [
                'label' => esc_html__('Background Parallax?', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'default' => 'yes',
                'return_value' => 'jarallax',
                'condition' => [
                    'tg_design_style' => ['layout-1', 'layout-3']
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tg_bg_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->end_controls_section();

        // tp_section_title
        $this->start_controls_section(
            'tp_section_title',
            [
                'label' => esc_html__('Title & Content', 'tpcore'),
                'condition' => [
                    'tg_design_style!' => ['layout-4'],
                ],
            ]
        );

        $this->add_control(
            'tp_section_title_show',
            [
                'label' => esc_html__('Section Title & Content', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'tg_sub_title',
            [
                'label' => esc_html__('Sub Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => tp_kses('Cleaning Service', 'tpcore'),
                'placeholder' => esc_html__('Type Sub Heading Text', 'tpcore'),
                'label_block' => true,
                'condition' => [
                    'tg_design_style!' => 'layout-3',
                ],
            ]
        );

        $this->add_control(
            'tg_title',
            [
                'label' => esc_html__('Title', 'tpcore'),
                'description' => tp_get_allowed_html_desc('intermediate'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => tp_kses('Best Cleaning Service in Home', 'tpcore'),
                'placeholder' => esc_html__('Type Heading Text', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_description',
            [
                'label' => esc_html__('Description', 'tpcore'),
                'description' => tp_get_allowed_html_desc('intermediate'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Lorem ipsum dolor sit amet consectetur. Ut tellus suspendisse nulla aliquam. Risus rutrum tellus eget ultrices pretium nisi amet facilisis.', 'tpcore'),
                'placeholder' => esc_html__('Type section description here', 'tpcore'),
            ]
        );

        $this->add_control(
            'tg_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'tpcore'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'tpcore'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'tpcore'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'tpcore'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'tpcore'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'tpcore'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'tpcore'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_responsive_control(
            'tp_align',
            [
                'label' => esc_html__('Alignment', 'tpcore'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'text-left' => [
                        'title' => esc_html__('Left', 'tpcore'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__('Center', 'tpcore'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__('Right', 'tpcore'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle' => false,
            ]
        );

        $this->end_controls_section();

        // banner_info_list
        $this->start_controls_section(
            'tg_banner_info_list',
            [
                'label' => esc_html__('Banner Info List', 'tpcore'),
                'condition' => [
                    'tg_design_style' => 'layout-2',
                ],
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'banner_info_text',
            [
                'label' => esc_html__('Item Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Best Cleaning Company', 'tpcore'),
                'title' => esc_html__('Enter your text', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'banner_info_lists',
            [
                'label' => esc_html__('Info Lists', 'tpcore'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'banner_info_text' => esc_html__('Best Cleaning Company', 'tpcore'),
                    ],
                    [
                        'banner_info_text' => esc_html__('Highly Rated Cleaning', 'tpcore'),
                    ],
                    [
                        'banner_info_text' => esc_html__('Trusted Professionals', 'tpcore'),
                    ],
                    [
                        'banner_info_text' => esc_html__('We Are Committed', 'tpcore'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        // tg_btn_button_group
        $this->start_controls_section(
            'tg_btn_button_group',
            [
                'label' => esc_html__('Button 01', 'tpcore'),
                'condition' => [
                    'tg_design_style!' => ['layout-4'],
                ],
            ]
        );

        $this->add_control(
            'tg_button_show',
            [
                'label' => esc_html__('Show Button', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'tg_btn_text',
            [
                'label' => esc_html__('Button Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Discover MORE', 'tpcore'),
                'title' => esc_html__('Enter button text', 'tpcore'),
                'label_block' => true,
                'condition' => [
                    'tg_button_show' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'tg_btn_link_type',
            [
                'label' => esc_html__('Button Link Type', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
                'condition' => [
                    'tg_button_show' => 'yes'
                ],
            ]
        );
        $this->add_control(
            'tg_btn_link',
            [
                'label' => esc_html__('Button link', 'tpcore'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'tpcore'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'tg_btn_link_type' => '1',
                    'tg_button_show' => 'yes'
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tg_btn_page_link',
            [
                'label' => esc_html__('Select Button Page', 'tpcore'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => tp_get_all_pages(),
                'condition' => [
                    'tg_btn_link_type' => '2',
                    'tg_button_show' => 'yes'
                ]
            ]
        );
        $this->end_controls_section();

        // tg_btn_button_group 02
        $this->start_controls_section(
            'tg_btn_button_group2',
            [
                'label' => esc_html__('Button 02', 'tpcore'),
                'condition' => [
                    'tg_design_style!' => ['layout-2', 'layout-4'],
                ],
            ]
        );

        $this->add_control(
            'tg_button_show2',
            [
                'label' => esc_html__('Show Button', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'tg_btn_text2',
            [
                'label' => esc_html__('Button Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Our Services', 'tpcore'),
                'title' => esc_html__('Enter button text', 'tpcore'),
                'label_block' => true,
                'condition' => [
                    'tg_button_show2' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'tg_btn_link_type2',
            [
                'label' => esc_html__('Button Link Type', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
                'condition' => [
                    'tg_button_show2' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'tg_btn_link2',
            [
                'label' => esc_html__('Button link', 'tpcore'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'tpcore'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'tg_btn_link_type2' => '1',
                    'tg_button_show2' => 'yes'
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_btn_page_link2',
            [
                'label' => esc_html__('Select Button Page', 'tpcore'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => tp_get_all_pages(),
                'condition' => [
                    'tg_btn_link_type2' => '2',
                    'tg_button_show2' => 'yes'
                ]
            ]
        );

        $this->end_controls_section();

        // tg_banner_contact
        $this->start_controls_section(
            'tg_banner_contact',
            [
                'label' => esc_html__('Banner Contact', 'tpcore'),
                'condition' => [
                    'tg_design_style' => 'layout-2',
                ],
            ]
        );

        $this->add_control(
            'tg_show_contact',
            [
                'label' => esc_html__('Show Contact', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        if (tp_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'tg_banner_contact_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-phone-alt',
                ]
            );
        } else {
            $this->add_control(
                'tg_contact_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-phone-alt',
                        'library' => 'solid',
                    ],
                ]
            );
        }

        $this->add_control(
            'banner_contact_text',
            [
                'label' => esc_html__('Contact Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Call for help:', 'tpcore'),
                'title' => esc_html__('Enter text', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'banner_contact_number',
            [
                'label' => esc_html__('Contact Number', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('(+055) 6489 6448', 'tpcore'),
                'title' => esc_html__('Enter text', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // tg_banner_estimate
        $this->start_controls_section(
            'tg_banner_estimate',
            [
                'label' => esc_html__('Banner Estimate', 'tpcore'),
                'condition' => [
                    'tg_design_style' => 'layout-3',
                ],
            ]
        );

        $this->add_control(
            'tg_show_estimate',
            [
                'label' => esc_html__('Show Estimate Form', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'banner_estimate_title',
            [
                'label' => esc_html__('Estimate Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Get a Free Estimate', 'tpcore'),
                'title' => esc_html__('Enter text', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'banner_estimate_from',
            [
                'label' => esc_html__('Estimate Form ShortCode', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('[Enter Estimate Shortcode]', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        // Slider
        $this->start_controls_section(
            'tg_slider_area',
            [
                'label' => esc_html__('Slider Area', 'tpcore'),
                'condition' => [
                    'tg_design_style' => 'layout-4',
                ],
            ]
        );

        $slider = new \Elementor\Repeater();

        $slider->add_control(
            'slider_bg',
            [
                'label' => esc_html__('Choose Background Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $slider->add_control(
            'slider_sub_title',
            [
                'label' => esc_html__('Sub Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Best Cleaning Services', 'tpcore'),
                'label_block' => true,
            ]
        );

        $slider->add_control(
            'slider_title',
            [
                'label' => esc_html__('Title', 'tpcore'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Professional Cleaning service for your home', 'tpcore'),
                'label_block' => true,
            ]
        );

        $slider->add_control(
            'slider_button_show',
            [
                'label' => esc_html__('Show Button 01', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $slider->add_control(
            'slider_btn_text',
            [
                'label' => esc_html__('Button Text 01', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Discover More', 'tpcore'),
                'title' => esc_html__('Enter button text', 'tpcore'),
                'label_block' => true,
                'condition' => [
                    'slider_button_show' => 'yes'
                ],
            ]
        );

        $slider->add_control(
            'slider_btn_link_type',
            [
                'label' => esc_html__('Button Link Type 01', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
                'condition' => [
                    'slider_button_show' => 'yes'
                ],
            ]
        );

        $slider->add_control(
            'slider_btn_link',
            [
                'label' => esc_html__('Button link 01', 'tpcore'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'tpcore'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'slider_btn_link_type' => '1',
                    'slider_button_show' => 'yes'
                ],
                'label_block' => true,
            ]
        );

        $slider->add_control(
            'slider_btn_page_link',
            [
                'label' => esc_html__('Select Button Page 01', 'tpcore'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => tp_get_all_pages(),
                'condition' => [
                    'slider_btn_link_type' => '2',
                    'slider_button_show' => 'yes'
                ]
            ]
        );

        $slider->add_control(
            'slider_button_show2',
            [
                'label' => esc_html__('Show Button 02', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $slider->add_control(
            'slider_btn_text2',
            [
                'label' => esc_html__('Button Text 02', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Our Services', 'tpcore'),
                'title' => esc_html__('Enter button text', 'tpcore'),
                'label_block' => true,
                'condition' => [
                    'slider_button_show2' => 'yes'
                ],
            ]
        );

        $slider->add_control(
            'slider_btn_link_type2',
            [
                'label' => esc_html__('Button Link Type 02', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
                'condition' => [
                    'slider_button_show2' => 'yes'
                ],
            ]
        );

        $slider->add_control(
            'slider_btn_link2',
            [
                'label' => esc_html__('Button link 02', 'tpcore'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'tpcore'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'slider_btn_link_type2' => '1',
                    'slider_button_show2' => 'yes'
                ],
                'label_block' => true,
            ]
        );

        $slider->add_control(
            'slider_btn_page_link2',
            [
                'label' => esc_html__('Select Button Page 02', 'tpcore'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => tp_get_all_pages(),
                'condition' => [
                    'slider_btn_link_type2' => '2',
                    'slider_button_show2' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'slider_info_lists',
            [
                'label' => esc_html__('Slider Lists', 'tpcore'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $slider->get_controls(),
                'default' => [
                    [
                        'slider_sub_title' => esc_html__('Best Cleaning Services', 'tpcore'),
                    ],
                    [
                        'slider_sub_title' => esc_html__('Highly Rated Cleaning', 'tpcore'),
                    ],
                    [
                        'slider_sub_title' => esc_html__('Best Cleaning Company', 'tpcore'),
                    ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'exclude' => ['custom'],
                'default' => 'full',
            ]
        );

        $this->end_controls_section();


        // TAB_STYLE
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }


    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if (!empty($settings['tg_bg']['url'])) {
            $tg_bg_url = !empty($settings['tg_bg']['id']) ? wp_get_attachment_image_url($settings['tg_bg']['id'], $settings['tg_bg_size_size']) : $settings['tg_bg']['url'];
            $tg_bg_alt = get_post_meta($settings["tg_bg"]["id"], "_wp_attachment_image_alt", true);
        }

?>

        <?php if ($settings['tg_design_style']  == 'layout-2') :

            $this->add_render_attribute('title_args', 'class', 'title wow fadeInUp');
            $this->add_render_attribute('title_args', 'data-wow-delay', '.4s');

            // Link 01
            if ('2' == $settings['tg_btn_link_type']) {
                $this->add_render_attribute('tg-button-arg', 'href', get_permalink($settings['tg_btn_page_link']));
                $this->add_render_attribute('tg-button-arg', 'target', '_self');
                $this->add_render_attribute('tg-button-arg', 'rel', 'nofollow');
                $this->add_render_attribute('tg-button-arg', 'class', 'btn wow fadeInLeft');
                $this->add_render_attribute('tg-button-arg', 'data-wow-delay', '1s');
            } else {
                if (!empty($settings['tg_btn_link']['url'])) {
                    $this->add_link_attributes('tg-button-arg', $settings['tg_btn_link']);
                    $this->add_render_attribute('tg-button-arg', 'class', 'btn wow fadeInLeft');
                    $this->add_render_attribute('tg-button-arg', 'data-wow-delay', '1s');
                }
            }

        ?>

            <script>
                jQuery(document).ready(function($) {

                    /*=============================================
                        =           Data Background             =
                    =============================================*/
                    $("[data-background]").each(function() {
                        $(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
                    })

                });
            </script>

            <!-- banner-area -->
            <section class="banner-area-two banner-bg-two" data-background="<?php echo esc_url($tg_bg_url); ?>">
                <div class="container-fluid p-0">
                    <div class="row justify-content-end g-0">
                        <div class="col-lg-6">
                            <div class="banner-content-two">

                                <?php if (!empty($settings['tp_section_title_show'])) : ?>

                                    <?php if (!empty($settings['tg_sub_title'])) : ?>
                                        <span class="sub-title wow fadeInUp" data-wow-delay=".2s"><?php echo tp_kses($settings['tg_sub_title']); ?></span>
                                    <?php endif; ?>

                                    <?php
                                    if (!empty($settings['tg_title'])) :
                                        printf(
                                            '<%1$s %2$s>%3$s</%1$s>',
                                            tag_escape($settings['tg_title_tag']),
                                            $this->get_render_attribute_string('title_args'),
                                            tp_kses($settings['tg_title'])
                                        );
                                    endif;
                                    ?>

                                    <?php if (!empty($settings['tg_description'])) : ?>
                                        <p class="wow fadeInUp" data-wow-delay=".6s"><?php echo tp_kses($settings['tg_description']); ?></p>
                                    <?php endif; ?>

                                <?php endif; ?>

                                <ul class="list-wrap wow fadeInUp" data-wow-delay=".8s">
                                    <?php foreach ($settings['banner_info_lists'] as $item) : ?>
                                        <li><i class="fas fa-check-circle"></i><?php echo esc_html($item['banner_info_text']); ?></li>
                                    <?php endforeach; ?>
                                </ul>

                                <div class="banner-content-bottom">

                                    <?php if (!empty($settings['tg_button_show'])) : ?>
                                        <a <?php echo $this->get_render_attribute_string('tg-button-arg'); ?>>
                                            <?php echo $settings['tg_btn_text']; ?>
                                        </a>
                                    <?php endif; ?>

                                    <?php if (!empty($settings['tg_show_contact'])) : ?>
                                        <div class="banner-contact wow fadeInRight" data-wow-delay="1s">

                                            <?php if (!empty($settings['tg_banner_contact_icon']) || !empty($settings['tg_contact_selected_icon']['value'])) : ?>
                                                <div class="icon">
                                                    <?php tp_render_icon($settings, 'tg_banner_contact_icon', 'tg_contact_selected_icon'); ?>
                                                </div>
                                            <?php endif; ?>

                                            <div class="content">
                                                <span><?php echo esc_html($settings['banner_contact_text']); ?></span>
                                                <a href="tel:<?php echo esc_attr($settings['banner_contact_number']); ?>"><?php echo esc_html($settings['banner_contact_number']); ?></a>
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                </div>

                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- banner-area-end -->

        <?php elseif ($settings['tg_design_style']  == 'layout-3') :

            $this->add_render_attribute('title_args', 'class', 'title');
            $this->add_render_attribute('title_args', 'data-aos', 'fade-right');
            $this->add_render_attribute('title_args', 'data-aos-delay', '0');

            // Link 01
            if ('2' == $settings['tg_btn_link_type']) {
                $this->add_render_attribute('tg-button-arg', 'href', get_permalink($settings['tg_btn_page_link']));
                $this->add_render_attribute('tg-button-arg', 'target', '_self');
                $this->add_render_attribute('tg-button-arg', 'rel', 'nofollow');
                $this->add_render_attribute('tg-button-arg', 'class', 'btn');
            } else {
                if (!empty($settings['tg_btn_link']['url'])) {
                    $this->add_link_attributes('tg-button-arg', $settings['tg_btn_link']);
                    $this->add_render_attribute('tg-button-arg', 'class', 'btn');
                }
            }

            // Link 02
            if ('2' == $settings['tg_btn_link_type2']) {
                $this->add_render_attribute('tg-button-arg2', 'href', get_permalink($settings['tg_btn_page_link2']));
                $this->add_render_attribute('tg-button-arg2', 'target', '_self');
                $this->add_render_attribute('tg-button-arg2', 'rel', 'nofollow');
                $this->add_render_attribute('tg-button-arg2', 'class', 'btn btn-two');
            } else {
                if (!empty($settings['tg_btn_link2']['url'])) {
                    $this->add_link_attributes('tg-button-arg2', $settings['tg_btn_link2']);
                    $this->add_render_attribute('tg-button-arg2', 'class', 'btn btn-two');
                }
            }

        ?>

            <script>
                jQuery(document).ready(function($) {

                    /*=============================================
                        =           Data Background             =
                    =============================================*/
                    $("[data-background]").each(function() {
                        $(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
                    })

                    /*=============================================
                        =      Jarallax Active  	         =
                    =============================================*/
                    $('.jarallax').jarallax({
                        speed: 0.2,
                    });

                });
            </script>

            <!-- banner-area -->
            <section class="banner-area-three <?php echo esc_attr($settings['tg_disable_parallax']); ?> banner-bg-three" data-background="<?php echo esc_url($tg_bg_url); ?>">
                <div class="container">
                    <div class="row align-items-center justify-content-center">

                        <?php if (!empty($settings['tg_show_estimate'])) : ?>
                            <div class="col-lg-6 col-md-10 order-0 order-lg-2">
                                <div class="banner-form-wrap">
                                    <?php if (!empty($settings['banner_estimate_title'])) : ?>
                                        <h2 class="title"><?php echo tp_kses($settings['banner_estimate_title']); ?></h2>
                                    <?php endif; ?>
                                    <?php echo do_shortcode($settings['banner_estimate_from']); ?>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php $col_12 = $settings['tg_show_estimate'] ? 'col-lg-6' : 'col-12'; ?>
                        <div class="<?php echo esc_attr($col_12); ?>">
                            <div class="banner-content-three">

                                <?php
                                if (!empty($settings['tg_title'])) :
                                    printf(
                                        '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape($settings['tg_title_tag']),
                                        $this->get_render_attribute_string('title_args'),
                                        tp_kses($settings['tg_title'])
                                    );
                                endif;
                                ?>

                                <?php if (!empty($settings['tg_description'])) : ?>
                                    <p data-aos="fade-right" data-aos-delay="300"><?php echo tp_kses($settings['tg_description']); ?></p>
                                <?php endif; ?>

                                <?php if (!empty($settings['tg_button_show'] || $settings['tg_button_show2'])) : ?>
                                    <div class="banner-btn" data-aos="fade-right" data-aos-delay="600">

                                        <?php if (!empty($settings['tg_button_show'])) : ?>
                                            <a <?php echo $this->get_render_attribute_string('tg-button-arg'); ?>>
                                                <?php echo $settings['tg_btn_text']; ?>
                                            </a>
                                        <?php endif; ?>

                                        <?php if (!empty($settings['tg_button_show2'])) : ?>
                                            <a <?php echo $this->get_render_attribute_string('tg-button-arg2'); ?>>
                                                <?php echo $settings['tg_btn_text2']; ?>
                                            </a>
                                        <?php endif; ?>

                                    </div>
                                <?php endif; ?>

                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- banner-area-end -->

        <?php elseif ($settings['tg_design_style']  == 'layout-4') : ?>

            <script>
                jQuery(document).ready(function($) {

                    /*=============================================
                        =           Data Background             =
                    =============================================*/
                    $("[data-background]").each(function() {
                        $(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
                    });

                    /*=============================================
                    =          Slider Active        =
                    =============================================*/
                    $('.slider-active').slick({
                        autoplay: false,
                        autoplaySpeed: 10000,
                        dots: true,
                        fade: true,
                        arrows: false,
                        responsive: [{
                            breakpoint: 767,
                            settings: {
                                dots: false,
                                arrows: false
                            }
                        }]
                    }).slickAnimation();

                });
            </script>

            <!-- slider-area -->
            <section class="slider-area">
                <div class="slider-active">
                    <?php foreach ($settings['slider_info_lists'] as $item) :

                        if (!empty($item['slider_bg']['url'])) {
                            $tg_slider_image_url = !empty($item['slider_bg']['id']) ? wp_get_attachment_image_url($item['slider_bg']['id'], $settings['thumbnail_size']) : $item['slider_bg']['url'];
                            $tg_slider_image_alt = get_post_meta($item["slider_bg"]["id"], "_wp_attachment_image_alt", true);
                        }

                        // btn Link 01
                        if ('2' == $item['slider_btn_link_type']) {
                            $link = get_permalink($item['slider_btn_page_link']);
                            $target = '_self';
                            $rel = 'nofollow';
                        } else {
                            $link = !empty($item['slider_btn_link']['url']) ? $item['slider_btn_link']['url'] : '';
                            $target = !empty($item['slider_btn_link']['is_external']) ? '_blank' : '';
                            $rel = !empty($item['slider_btn_link']['nofollow']) ? 'nofollow' : '';
                        }

                        // btn Link 02
                        if ('2' == $item['slider_btn_link_type2']) {
                            $link2 = get_permalink($item['slider_btn_page_link2']);
                            $target2 = '_self';
                            $rel2 = 'nofollow';
                        } else {
                            $link2 = !empty($item['slider_btn_link2']['url']) ? $item['slider_btn_link2']['url'] : '';
                            $target2 = !empty($item['slider_btn_link2']['is_external']) ? '_blank' : '';
                            $rel2 = !empty($item['slider_btn_link2']['nofollow']) ? 'nofollow' : '';
                        }

                    ?>
                        <div class="single-slider slider-bg" data-background="<?php echo esc_url( $tg_slider_image_url ); ?>">
                            <div class="container">
                                <div class="row">
                                    <div class="col-lg-7">
                                        <div class="slider-content" data-animation-in="fadeInUp" data-delay-in=".2">

                                            <?php if (!empty($item['slider_sub_title'])) : ?>
                                                <h4 class="sub-title">
                                                    <svg viewBox="0 0 41 44" fill="none" xmlns="http://www.w3.org/2000/svg">
                                                        <path d="M35.2826 37.5886C36.6662 36.9737 38.8185 36.205 40.8939 36.205C38.8185 36.205 36.6662 35.4363 35.2826 34.8213C34.6676 33.4377 33.8989 31.2854 33.8989 29.21C33.8989 31.2854 33.1303 33.4377 32.5153 34.8213C31.1317 35.4363 28.9794 36.205 26.9039 36.205C28.9794 36.205 31.1317 36.9737 32.5153 37.5886C33.1303 38.9722 33.8989 41.1246 33.8989 43.2C33.8989 41.1246 34.6676 38.9722 35.2826 37.5886Z" fill="currentcolor" />
                                                        <path d="M31.2085 13.5288C33.4377 12.5295 36.8968 11.2996 40.279 11.2996C36.8968 11.2996 33.4377 10.0698 31.2085 9.07046C30.2093 6.84128 28.9794 3.38221 28.9794 0C28.9794 3.38221 27.7495 6.84128 26.7502 9.07046C24.521 10.0698 21.0619 11.2996 17.6797 11.2996C21.0619 11.2996 24.521 12.5295 26.7502 13.5288C27.7495 15.758 28.9794 19.2171 28.9794 22.5993C28.9794 19.2171 30.2093 15.758 31.2085 13.5288Z" fill="currentcolor" />
                                                        <path d="M16.6036 31.7467C19.2939 30.5936 23.5986 28.9794 27.6726 28.9794C23.5986 28.9794 19.2939 27.442 16.6036 26.2121C15.3737 23.5986 13.8363 19.294 13.8363 15.22C13.8363 19.294 12.2989 23.5986 11.069 26.289C8.37865 27.442 4.07402 29.0563 0 29.0563C4.07402 29.0563 8.37865 30.5936 11.069 31.8235C12.2989 34.4371 13.8363 38.7417 13.8363 42.8926C13.8363 38.7417 15.3737 34.4371 16.6036 31.7467Z" fill="currentcolor" />
                                                    </svg>
                                                    <?php echo tp_kses($item['slider_sub_title']) ?>
                                                </h4>
                                            <?php endif; ?>

                                            <?php if (!empty($item['slider_title'])) : ?>
                                                <h2 class="title" data-animation-in="fadeInUp" data-delay-in=".4"><?php echo tp_kses($item['slider_title']) ?></h2>
                                            <?php endif; ?>

                                            <?php if (!empty($item['slider_button_show'] || $item['slider_button_show2'])) : ?>
                                                <div class="slider-btn">

                                                    <?php if (!empty($item['slider_button_show'])) : ?>
                                                        <a target="<?php echo esc_attr($target); ?>" rel="<?php echo esc_attr($rel); ?>" href="<?php echo esc_url($link); ?>" class="btn" data-animation-in="fadeInLeft" data-delay-in=".6"><?php echo esc_html($item['slider_btn_text']) ?></a>
                                                    <?php endif; ?>

                                                    <?php if (!empty($item['slider_button_show2'])) : ?>
                                                        <a target="<?php echo esc_attr($target2); ?>" rel="<?php echo esc_attr($rel2); ?>" href="<?php echo esc_url($link2); ?>" class="btn btn-two" data-animation-in="fadeInRight" data-delay-in=".6"><?php echo esc_html($item['slider_btn_text2']) ?></a>
                                                    <?php endif; ?>

                                                </div>
                                            <?php endif; ?>

                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </section>
            <!-- slider-area-end -->


        <?php else :

            $this->add_render_attribute('title_args', 'class', 'title wow fadeInUp');
            $this->add_render_attribute('title_args', 'data-wow-delay', '0.4s');

            // Link 01
            if ('2' == $settings['tg_btn_link_type']) {
                $this->add_render_attribute('tg-button-arg', 'href', get_permalink($settings['tg_btn_page_link']));
                $this->add_render_attribute('tg-button-arg', 'target', '_self');
                $this->add_render_attribute('tg-button-arg', 'rel', 'nofollow');
                $this->add_render_attribute('tg-button-arg', 'class', 'btn wow fadeInLeft');
                $this->add_render_attribute('tg-button-arg', 'data-wow-delay', '.8s');
            } else {
                if (!empty($settings['tg_btn_link']['url'])) {
                    $this->add_link_attributes('tg-button-arg', $settings['tg_btn_link']);
                    $this->add_render_attribute('tg-button-arg', 'class', 'btn wow fadeInLeft');
                    $this->add_render_attribute('tg-button-arg', 'data-wow-delay', '.8s');
                }
            }

            // Link 02
            if ('2' == $settings['tg_btn_link_type2']) {
                $this->add_render_attribute('tg-button-arg2', 'href', get_permalink($settings['tg_btn_page_link2']));
                $this->add_render_attribute('tg-button-arg2', 'target', '_self');
                $this->add_render_attribute('tg-button-arg2', 'rel', 'nofollow');
                $this->add_render_attribute('tg-button-arg2', 'class', 'btn btn-two wow fadeInRight');
                $this->add_render_attribute('tg-button-arg2', 'data-wow-delay', '.8s');
            } else {
                if (!empty($settings['tg_btn_link2']['url'])) {
                    $this->add_link_attributes('tg-button-arg2', $settings['tg_btn_link2']);
                    $this->add_render_attribute('tg-button-arg2', 'class', 'btn btn-two wow fadeInRight');
                    $this->add_render_attribute('tg-button-arg2', 'data-wow-delay', '.8s');
                }
            }

        ?>

            <script>
                jQuery(document).ready(function($) {

                    /*=============================================
                        =           Data Background             =
                    =============================================*/
                    $("[data-background]").each(function() {
                        $(this).css("background-image", "url(" + $(this).attr("data-background") + ")")
                    })

                    /*=============================================
                        =      Jarallax Active  	         =
                    =============================================*/
                    $('.jarallax').jarallax({
                        speed: 0.2,
                    });

                });
            </script>

            <!-- banner-area -->
            <section class="banner-area <?php echo esc_attr($settings['tg_disable_parallax']); ?> banner-bg" data-background="<?php echo esc_url($tg_bg_url); ?>">
                <div class="container">
                    <div class="row justify-content-end">
                        <div class="col-lg-7">
                            <div class="banner-content">
                                <?php if (!empty($settings['tp_section_title_show'])) : ?>
                                    <?php if (!empty($settings['tg_sub_title'])) : ?>
                                        <span class="sub-title wow fadeInUp" data-wow-delay=".2s"><?php echo tp_kses($settings['tg_sub_title']); ?></span>
                                    <?php endif; ?>

                                    <?php
                                    if (!empty($settings['tg_title'])) :
                                        printf(
                                            '<%1$s %2$s>%3$s</%1$s>',
                                            tag_escape($settings['tg_title_tag']),
                                            $this->get_render_attribute_string('title_args'),
                                            tp_kses($settings['tg_title'])
                                        );
                                    endif;
                                    ?>

                                    <?php if (!empty($settings['tg_description'])) : ?>
                                        <p class="wow fadeInUp" data-wow-delay=".6s"><?php echo tp_kses($settings['tg_description']); ?></p>
                                    <?php endif; ?>

                                <?php endif; ?>

                                <?php if (!empty($settings['tg_button_show'] || $settings['tg_button_show2'])) : ?>
                                    <div class="banner-btn">

                                        <?php if (!empty($settings['tg_button_show'])) : ?>
                                            <a <?php echo $this->get_render_attribute_string('tg-button-arg'); ?>>
                                                <?php echo $settings['tg_btn_text']; ?>
                                            </a>
                                        <?php endif; ?>

                                        <?php if (!empty($settings['tg_button_show2'])) : ?>
                                            <a <?php echo $this->get_render_attribute_string('tg-button-arg2'); ?>>
                                                <?php echo $settings['tg_btn_text2']; ?>
                                            </a>
                                        <?php endif; ?>

                                    </div>
                                <?php endif; ?>

                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- banner-area-end -->

        <?php endif; ?>

<?php
    }
}

$widgets_manager->register(new TG_Hero_Banner());
