<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_History extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'tp-history';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Our History', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // tg_history_section
        $this->start_controls_section(
            'tg_history_section',
            [
                'label' => esc_html__('History List', 'tpcore'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'tg_year',
            [
                'label' => esc_html__('Year', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('2018', 'tpcore'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'tg_history_title',
            [
                'label' => esc_html__('Title', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('We already branches across the country', 'tpcore'),
                'placeholder' => esc_html__('Enter Title Text', 'tpcore'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'tg_history_desc',
            [
                'label' => esc_html__('History Description', 'tpcore'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => tp_kses('Lorem dolor consectetur tellus suspendisse nulla aliquam at the ultrices the pretium', 'tpcore'),
                'placeholder' => esc_html__('Enter Your History Desc', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_history_items',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => esc_html__('History Items', 'tpcore'),
                'default' => [
                    [
                        'tg_year' => esc_html__('2018', 'tpcore'),
                        'tg_history_title' => esc_html__('We already branches across the country', 'tpcore'),
                    ],
                    [
                        'tg_year' => esc_html__('2019', 'tpcore'),
                        'tg_history_title' => esc_html__('Cleaning Authority for a Free Estimate', 'tpcore'),
                    ],
                ]
            ]
        );

        $this->end_controls_section();

        // STYLE TAB
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>

        <script>
            jQuery(document).ready(function($) {

                /*=============================================
                    =    		History Active		      =
                =============================================*/
                $('.history-active').slick({
                    dots: false,
                    infinite: true,
                    speed: 1000,
                    autoplay: true,
                    arrows: true,
                    prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',
                    nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',
                    appendArrows: ".history-nav",
                    slidesToShow: 4,
                    slidesToScroll: 1,
                    responsive: [{
                            breakpoint: 1200,
                            settings: {
                                slidesToShow: 3,
                                slidesToScroll: 1,
                                infinite: true,
                            }
                        },
                        {
                            breakpoint: 992,
                            settings: {
                                slidesToShow: 2,
                                slidesToScroll: 1
                            }
                        },
                        {
                            breakpoint: 767,
                            settings: {
                                slidesToShow: 2,
                                slidesToScroll: 1,
                                arrows: false,
                            }
                        },
                        {
                            breakpoint: 575,
                            settings: {
                                slidesToShow: 1,
                                slidesToScroll: 1,
                                arrows: false,
                            }
                        },
                    ]
                });

            });
        </script>

        <div class="history-item-wrap">
            <div class="row history-active">
                <?php foreach ($settings['tg_history_items'] as $item) : ?>
                    <div class="col-lg-3">
                        <div class="history-item">
                            <div class="history-date">
                                <h2 class="title"><?php echo tp_kses($item['tg_year']) ?></h2>
                            </div>
                            <div class="history-content">
                                <h2 class="title"><?php echo tp_kses($item['tg_history_title']) ?></h2>
                                <p><?php echo tp_kses($item['tg_history_desc']) ?></p>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
            <div class="history-nav"></div>
        </div>

<?php
    }
}

$widgets_manager->register(new TG_History());
