<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_Before_After extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'tp-image-difference';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Image Difference', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // tg_image_difference_section
        $this->start_controls_section(
            'tg_image_difference_section',
            [
                'label' => esc_html__('Image Difference', 'tpcore'),
            ]
        );

        $this->add_control(
            'tg_bg',
            [
                'label' => esc_html__('Choose Before Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'tg_bg2',
            [
                'label' => esc_html__('Choose After Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tg_bg_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->end_controls_section();

        // STYLE TAB
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if (!empty($settings['tg_bg']['url'])) {
            $tg_bg_url = !empty($settings['tg_bg']['id']) ? wp_get_attachment_image_url($settings['tg_bg']['id'], $settings['tg_bg_size_size']) : $settings['tg_bg']['url'];
            $tg_bg_alt = get_post_meta($settings["tg_bg"]["id"], "_wp_attachment_image_alt", true);
        }

        if (!empty($settings['tg_bg2']['url'])) {
            $tg_bg_url2 = !empty($settings['tg_bg2']['id']) ? wp_get_attachment_image_url($settings['tg_bg2']['id'], $settings['tg_bg_size_size']) : $settings['tg_bg2']['url'];
            $tg_bg_alt2 = get_post_meta($settings["tg_bg2"]["id"], "_wp_attachment_image_alt", true);
        }

?>

        <script>
            jQuery(document).ready(function($) {

                /*=============================================
                    =    		beforeAfter Active	        =
                =============================================*/
                $.fn.BeerSlider = function(options) {
                    options = options || {};
                    return this.each(function() {
                        new BeerSlider(this, options);
                    });
                };
                $(".beer-slider").each(function(index, el) {
                    $(el).BeerSlider({
                        start: $(el).data("start")
                    })
                });

            });
        </script>

        <div id="slider1" class="beer-slider" data-start="50">
            <?php if (!empty($settings['tg_bg']['url'])) : ?>
                <img src="<?php echo esc_url($tg_bg_url); ?>" alt="<?php echo esc_attr($tg_bg_alt); ?>">
            <?php endif; ?>

            <?php if (!empty($settings['tg_bg2']['url'])) : ?>
                <div class="beer-reveal">
                    <img src="<?php echo esc_url($tg_bg_url2); ?>" alt="<?php echo esc_attr($tg_bg_alt2); ?>">
                </div>
            <?php endif; ?>

        </div>

<?php
    }
}

$widgets_manager->register(new TG_Before_After());
