<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_Project_Details extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'tg-project-details';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Project Details', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // info group
        $this->start_controls_section(
            'project_info_list',
            [
                'label' => esc_html__('Info List', 'tpcore'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'info_sub',
            [
                'label' => esc_html__('Info Subject', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Clients:', 'tpcore'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'info_text',
            [
                'label' => esc_html__('Info Text', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Mike Hardson', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'info_list',
            [
                'label' => esc_html__('Info Repeater', 'tpcore'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' =>  $repeater->get_controls(),
                'default' => [
                    [
                        'info_sub' => esc_html__('Clients:', 'tpcore'),
                        'info_text' => esc_html__('Mike Hardson', 'tpcore'),
                    ],
                    [
                        'info_sub' => esc_html__('Category:', 'tpcore'),
                        'info_text' => esc_html__('Cleaning, Washing', 'tpcore'),
                    ],
                    [
                        'info_sub' => esc_html__('Date:', 'tpcore'),
                        'info_text' => esc_html__('26 March, 2023', 'tpcore'),
                    ],

                ],
                'title_field' => '{{{ info_sub }}}',
            ]
        );

        $this->end_controls_section();

        // social group
        $this->start_controls_section(
            'project_social_list',
            [
                'label' => esc_html__('Social List', 'tpcore'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'facebook_link',
            [
                'label' => esc_html__('Facebook Link', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'twitter_link',
            [
                'label' => esc_html__('Twitter Link', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'linkedin_link',
            [
                'label' => esc_html__('Linkedin Link', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'instagram_link',
            [
                'label' => esc_html__('Instagram Link', 'tpcore'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('#', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // Style Tab
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .cs-section_title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>

        <div class="project-details-thumb">
            <img src="<?php echo get_the_post_thumbnail_url(get_the_ID(), ''); ?>" alt="<?php echo esc_attr__('Image', 'tpcore') ?>">
            <div class="project-info-wrap">

                <?php foreach ($settings['info_list'] as $item) : ?>
                    <div class="project-info-item">
                        <?php if (!empty($item['info_sub'])) : ?>
                            <span><?php echo tp_kses($item['info_sub']) ?></span>
                        <?php endif; ?>

                        <?php if (!empty($item['info_text'])) : ?>
                            <h5 class="title"><?php echo tp_kses($item['info_text']) ?></h5>
                        <?php endif; ?>

                    </div>
                <?php endforeach; ?>

                <div class="team-details-social">
                    <ul class="list-wrap">
                        <?php if (!empty($settings['facebook_link'])) : ?>
                            <li><a href="<?php echo esc_url( $settings['facebook_link'] ) ?>"><i class="fab fa-facebook-f"></i></a></li>
                        <?php endif; ?>

                        <?php if (!empty($settings['twitter_link'])) : ?>
                            <li><a href="<?php echo esc_url( $settings['twitter_link'] ) ?>"><i class="fab fa-twitter"></i></a></li>
                        <?php endif; ?>

                        <?php if (!empty($settings['linkedin_link'])) : ?>
                            <li><a href="<?php echo esc_url( $settings['linkedin_link'] ) ?>"><i class="fab fa-linkedin-in"></i></a></li>
                        <?php endif; ?>

                        <?php if (!empty($settings['instagram_link'])) : ?>
                            <li><a href="<?php echo esc_url( $settings['instagram_link'] ) ?>"><i class="fab fa-instagram"></i></a></li>
                        <?php endif; ?>

                    </ul>
                </div>

            </div>
        </div>

<?php
    }
}

$widgets_manager->register(new TG_Project_Details());
