<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_PORTFOLIO_PAGINATION extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'tg-portfolio-pagination';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Portfolio Pagination', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {

        // tg_section_title
        $this->start_controls_section(
            'tg_section_title',
            [
                'label' => esc_html__('Next / Prev Pagination', 'tpcore'),
            ]
        );

        $this->add_control(
            'tg_prev_text',
            [
                'label' => esc_html__('Prev Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => tp_kses('Previous', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'tg_next_text',
            [
                'label' => esc_html__('Next Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => tp_kses('Next', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .cs-text_btn' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
    ?>

        <div class="project-next-prev">
            <?php
            $prev_post = get_previous_post();
            if ($prev_post) :
            ?>
                <div class="post prev-post">
                    <a href="<?php echo get_permalink($prev_post->ID); ?>"><?php echo tp_kses($settings['tg_prev_text']) ?><i class="fas fa-chevron-left"></i></a>
                </div>
            <?php endif; ?>

            <?php
            $next_post = get_next_post();
            if ($next_post) :
            ?>
                <div class="post next-post">
                    <a href="<?php echo get_permalink($next_post->ID); ?>"><?php echo tp_kses($settings['tg_next_text']) ?><i class="fas fa-chevron-right"></i></a>
                </div>
            <?php endif; ?>

        </div>

<?php
    }
}

$widgets_manager->register(new TG_PORTFOLIO_PAGINATION());