<?php

namespace TPCore\Widgets;

use Elementor\Widget_Base;
use \Elementor\Control_Media;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Css_Filter;
use \Elementor\Repeater;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Core\Schemes\Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Box_Shadow;
use TPCore\Elementor\Controls\Group_Control_TPBGGradient;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Clentac Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TG_Team_Details extends Widget_Base
{

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'team-details';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Team Details', 'tpcore');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'tp-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['tpcore'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['tpcore'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */

    protected function register_controls()
    {

        // _tp_image
        $this->start_controls_section(
            '_tp_image',
            [
                'label' => esc_html__('Thumbnail', 'tpcore'),
            ]
        );
        $this->add_control(
            'tg_image',
            [
                'label' => esc_html__('Choose Image', 'tpcore'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section();

        // Name
        $this->start_controls_section(
            '_section_name_info',
            [
                'label' => esc_html__('Team Name Info', 'tpcore'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'team_name',
            [
                'label' => esc_html__('Name', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('William Adams', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_designation',
            [
                'label' => esc_html__('Designation', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Window Cleaner', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // Social
        $this->start_controls_section(
            '_section_social',
            [
                'label' => esc_html__('Social Profiles', 'tpcore'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_profiles',
            [
                'label' => esc_html__('Show Profiles', 'tpcore'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'tpcore'),
                'label_off' => esc_html__('Hide', 'tpcore'),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
                'style_transfer' => true,
            ]
        );

        $repeater = new Repeater();

        if (tp_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'tg_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-facebook',
                ]
            );
        } else {
            $repeater->add_control(
                'tg_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fab fa-facebook-f',
                        'library' => 'solid',
                    ],
                ]
            );
        }

        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Profile Link', 'tpcore'),
                'placeholder' => esc_html__('Add your profile link', 'tpcore'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'autocomplete' => false,
                'show_external' => false,
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'profiles',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'link' => ['url' => 'https://facebook.com/'],
                    ],
                    [
                        'link' => ['url' => 'https://twitter.com/'],
                    ],
                    [
                        'link' => ['url' => 'https://linkedin.com/'],
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        // Info
        $this->start_controls_section(
            '_section_info',
            [
                'label' => esc_html__('Team Info', 'tpcore'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'team_website',
            [
                'label' => esc_html__('Website Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Website : ', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_website_url',
            [
                'label' => esc_html__('Website URL', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('yourwebsite.com', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_phone',
            [
                'label' => esc_html__('Phone Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Phone :', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_phone_url',
            [
                'label' => esc_html__('Phone Number', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('44-20-7328-4499', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_email',
            [
                'label' => esc_html__('Email Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Email :', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_email_url',
            [
                'label' => esc_html__('Email', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('custom@gmail.com', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_address',
            [
                'label' => esc_html__('Address Text', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Address :', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_address_url',
            [
                'label' => esc_html__('Address', 'tpcore'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('380 Albert St, Melbourne', 'tpcore'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        // TAB_STYLE
        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'tpcore'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_transform',
            [
                'label' => __('Text Transform', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => __('None', 'tpcore'),
                    'uppercase' => __('UPPERCASE', 'tpcore'),
                    'lowercase' => __('lowercase', 'tpcore'),
                    'capitalize' => __('Capitalize', 'tpcore'),
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display(); ?>

        <div class="team-details-img">

            <?php if ($settings['tg_image']['url']) : ?>
                <img src="<?php echo esc_url($settings['tg_image']['url']); ?>" alt="<?php echo esc_attr__( 'Image', 'tpcore' ) ?>">
            <?php endif; ?>

            <div class=" team-details-info">

                <?php if (!empty($settings['team_name'])) : ?>
                    <h2 class="title"><?php echo esc_html($settings['team_name']); ?></h2>
                <?php endif; ?>

                <?php if (!empty($settings['team_designation'])) : ?>
                    <span><?php echo esc_html($settings['team_designation']); ?></span>
                <?php endif; ?>

                <div class="team-details-social">
                    <ul class="list-wrap">
                        <?php foreach ($settings['profiles'] as $item) : ?>
                            <li>
                                <a href="<?php echo esc_url($item['link']) ?>">
                                    <?php if (!empty($item['tg_icon']) || !empty($item['tg_selected_icon']['value'])) : ?>
                                        <?php tp_render_icon($item, 'tg_icon', 'tg_selected_icon'); ?>
                                    <?php endif; ?>
                                </a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>

                <div class="info-list">
                    <ul class="list-wrap">

                        <?php if (!empty($settings['team_website'])) : ?>
                            <li><?php echo esc_html($settings['team_website']) ?> <a href="<?php echo esc_url($settings['team_website_url']) ?>"><?php echo esc_html($settings['team_website_url']) ?></a></li>
                        <?php endif; ?>

                        <?php if (!empty($settings['team_phone'])) : ?>
                            <li><?php echo esc_html($settings['team_phone']) ?> <a href="tel:<?php echo esc_attr($settings['team_phone_url']) ?>"><?php echo esc_html($settings['team_phone_url']) ?></a></li>
                        <?php endif; ?>

                        <?php if (!empty($settings['team_email'])) : ?>
                            <li><?php echo esc_html($settings['team_email']) ?> <a href="mailto:<?php echo esc_attr($settings['team_email_url']) ?>"><?php echo esc_html($settings['team_email_url']) ?></a></li>
                        <?php endif; ?>

                        <?php if (!empty($settings['team_address'])) : ?>
                            <li><?php echo esc_html($settings['team_address']) ?> <span><?php echo esc_html($settings['team_address_url']) ?></span></li>
                        <?php endif; ?>

                    </ul>
                </div>

            </div>
        </div>

<?php
    }
}

$widgets_manager->register(new TG_Team_Details());
