<?php

/**
 * Template part for displaying footer layout one
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package clentac
 */

// Footer Bg
$footer_bg_img = get_theme_mod('clentac_footer_bg');
$footer_bg_color = get_theme_mod('clentac_footer_bg_color');
$clentac_footer_bg_url_from_page = function_exists('get_field') ? get_field('clentac_footer_bg') : '';
$clentac_footer_bg_color_from_page = function_exists('get_field') ? get_field('clentac_footer_bg_color') : '';


$bg_img = !empty($clentac_footer_bg_url_from_page['url']) ? $clentac_footer_bg_url_from_page['url'] : $footer_bg_img;

$bg_color = !empty($clentac_footer_bg_color_from_page) ? $clentac_footer_bg_color_from_page : $footer_bg_color;


// Footer Logo
$footer_logo_area = get_theme_mod('footer_logo_area', false);
$footer_logo_url = get_template_directory_uri() . '/assets/img/logo/secondary_logo.svg';
$footer_logo = get_theme_mod('footer_logo', $footer_logo_url);

$footer_top_padding = $footer_logo_area ? 'show-footer-logo' : 'hide-footer-logo';


// Copyright menu
$show_copyright_menu = get_theme_mod('show_copyright_menu', false);
$defaults_menu = [
    [
        'link_text' => esc_html__('Privacy policy', 'clentac'),
        'link_url'  => '#',
    ],
    [
        'link_text' => esc_html__('Terms & Conditions', 'clentac'),
        'link_url'  => '#',
    ],
];
$copyright_menu_repeater = get_theme_mod('copyright_menu_repeater', $defaults_menu);
$clentac_copyright_center = $show_copyright_menu ? 'col-lg-6 col-md-7' : 'col-12 text-center';



// Footer Columns
$footer_columns = 0;
$footer_widgets = get_theme_mod('footer_widget_number', 4);

for ($num = 1; $num <= $footer_widgets; $num++) {
    if (is_active_sidebar('footer-' . $num)) {
        $footer_columns++;
    }
}

switch ($footer_columns) {
    case '1':
        $footer_class[1] = 'col-lg-12';
        break;
    case '2':
        $footer_class[1] = 'col-lg-6 col-md-6';
        $footer_class[2] = 'col-lg-6 col-md-6';
        break;
    case '3':
        $footer_class[1] = 'col-lg-4 col-sm-6';
        $footer_class[2] = 'col-lg-4 col-sm-6';
        $footer_class[3] = 'col-lg-4 col-sm-6';
        break;
    case '4':
        $footer_class[1] = 'col-lg-3 col-sm-6';
        $footer_class[2] = 'col-lg-3 col-sm-6';
        $footer_class[3] = 'col-lg-3 col-sm-6';
        $footer_class[4] = 'col-lg-3 col-sm-6';
        break;
    default:
        $footer_class = 'col-lg-3 col-sm-6';
        break;
}

?>


<!-- footer-area -->
<footer>
    <div class="footer-area footer-bg" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">

        <?php if (is_active_sidebar('footer-1') or is_active_sidebar('footer-2') or is_active_sidebar('footer-3') or is_active_sidebar('footer-4')) : ?>
            <div class="footer-top <?php echo esc_attr($footer_top_padding); ?>">
                <div class="container">

                    <?php if (!empty($footer_logo_area)) : ?>
                        <div class="footer-logo-area">
                            <div class="row align-items-center">
                                <div class="col-md-4">
                                    <div class="logo">
                                        <a href="<?php print esc_url(home_url('/')); ?>">
                                            <img src="<?php print esc_url($footer_logo); ?>" height="auto" style="max-width: <?php echo get_theme_mod('logo_size_adjust', '186px'); ?>" alt="<?php print esc_attr__('Logo', 'clentac'); ?>" />
                                        </a>
                                    </div>
                                </div>
                                <div class="col-md-8">
                                    <div class="footer-social-menu">
                                        <?php clentac_footer_menu(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="row">
                        <?php
                        if ($footer_columns < 4) {
                            print '<div class="col-lg-3 col-sm-6">';
                            dynamic_sidebar('footer-1');
                            print '</div>';

                            print '<div class="col-lg-3 col-sm-6">';
                            dynamic_sidebar('footer-2');
                            print '</div>';

                            print '<div class="col-lg-3 col-sm-6">';
                            dynamic_sidebar('footer-3');
                            print '</div>';

                            print '<div class="col-lg-3 col-sm-6">';
                            dynamic_sidebar('footer-4');
                            print '</div>';
                        } else {
                            for ($num = 1; $num <= $footer_columns; $num++) {
                                if (!is_active_sidebar('footer-' . $num)) {
                                    continue;
                                }
                                print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                dynamic_sidebar('footer-' . $num);
                                print '</div>';
                            }
                        }
                        ?>
                    </div>

                </div>
            </div>
        <?php endif; ?>

        <div class="footer-bottom">
            <div class="container">
                <div class="row">
                    <div class="<?php echo esc_attr($clentac_copyright_center); ?>">
                        <div class="copyright-text">
                            <p><?php print clentac_copyright_text(); ?></p>
                        </div>
                    </div>

                    <?php if (!empty($show_copyright_menu)) : ?>
                        <div class="col-lg-6 col-md-5">
                            <div class="footer-bottom-menu">
                                <ul class="list-wrap">
                                    <?php foreach ($copyright_menu_repeater as $item) : ?>
                                        <li><a href="<?php echo esc_url($item['link_url']); ?>"><?php echo esc_html($item['link_text']); ?></a></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    <?php endif; ?>

                </div>
            </div>
        </div>

    </div>
</footer>
<!-- footer-area-end -->